pub fn float_arg_max_sorted_ascending<T>(ca: &ChunkedArray<T>) -> usizewhere
T: PolarsNumericType,Expand description
Safety
ca has a float dtype, has at least 1 non-null value and is sorted ascending
pub fn float_arg_max_sorted_ascending<T>(ca: &ChunkedArray<T>) -> usizewhere
T: PolarsNumericType,ca has a float dtype, has at least 1 non-null value and is sorted ascending