DataType

Enum DataType 

pub enum DataType {
Show 31 variants Boolean, UInt8, UInt16, UInt32, UInt64, UInt128, Int8, Int16, Int32, Int64, Int128, Float16, Float32, Float64, Decimal(usize, usize), String, Binary, BinaryOffset, Date, Datetime(TimeUnit, Option<TimeZone>), Duration(TimeUnit), Time, Array(Box<DataType>, usize), List(Box<DataType>), Object(&'static str), Null, Categorical(Arc<Categories>, Arc<CategoricalMapping>), Enum(Arc<FrozenCategories>, Arc<CategoricalMapping>), Struct(Vec<Field>), Map(Box<DataType>, Box<DataType>), Unknown(UnknownKind),
}

Variants



Boolean



UInt8



UInt16



UInt32



UInt64



UInt128



Int8



Int16



Int32



Int64



Int128



Float16



Float32



Float64



Decimal(usize, usize)

Available on crate feature dtype-decimal only.

Fixed point decimal type optional precision and non-negative scale. This is backed by a signed 128-bit integer which allows for up to 38 significant digits. Meaning max precision is 38.



String

String data



Binary



BinaryOffset



Date

A 32-bit date representing the elapsed time since UNIX epoch (1970-01-01) in days (32 bits).



Datetime(TimeUnit, Option<TimeZone>)

A 64-bit date representing the elapsed time since UNIX epoch (1970-01-01) in the given timeunit (64 bits).



Duration(TimeUnit)

64-bit integer representing difference between times in milliseconds or nanoseconds



Time

A 64-bit time representing the elapsed time since midnight in nanoseconds



Array(Box<DataType>, usize)

Available on crate feature dtype-array only.

A nested list with a fixed size in each row



List(Box<DataType>)

A nested list with a variable size in each row



Object(&'static str)

Available on crate feature object only.

A generic type that can be used in a Series &’static str can be used to determine/set inner type



Null



Categorical(Arc<Categories>, Arc<CategoricalMapping>)

Available on crate feature dtype-categorical only.


Enum(Arc<FrozenCategories>, Arc<CategoricalMapping>)

Available on crate feature dtype-categorical only.


Struct(Vec<Field>)

Available on crate feature dtype-struct only.


Map(Box<DataType>, Box<DataType>)

Available on crate feature dtype-map only.

A map from keys to values, keys are unique and non-null.



Unknown(UnknownKind)

Implementations

Source

impl DataType

pub const IDX_DTYPE: DataType = { { DataType::UInt32 } }

pub fn pretty_format(&self) -> String

pub fn value_within_range(&self, other: AnyValue<'_>) -> bool

pub fn _month_days_ns_struct_type() -> DataType

Available on crate feature dtype-struct only.

Struct representation of the arrow month_day_nano_interval type.

pub fn is_known(&self) -> bool

Check if the whole dtype is known.

pub fn materialize_unknown( self, allow_unknown: bool, ) -> Result<DataType, PolarsError>

Materialize this datatype if it is unknown. All other datatypes are left unchanged.

pub fn get_shape(&self) -> Option<Vec<usize>>

Available on crate feature dtype-array only.

Get the full shape of a multidimensional array.

pub fn inner_dtype(&self) -> Option<&DataType>

Get the inner data type of a nested type.

pub fn into_inner_dtype(self) -> Option<DataType>

Get the inner data type of a nested type.

pub fn try_into_inner_dtype(self) -> Result<DataType, PolarsError>

Get the inner data type of a nested type.

pub fn leaf_dtype(&self) -> &DataType

Get the absolute inner data type of a nested type.

pub fn array_leaf_dtype(&self) -> Option<&DataType>

Available on crate feature dtype-array only.

Get the inner data type of a multidimensional array.

pub fn cast_leaf(&self, to: DataType) -> DataType

Cast the leaf types of Lists/Arrays and keep the nesting.

pub fn map_leaves<F>(self, f: &mut F) -> DataType
where F: FnMut(DataType) -> DataType,

Map all leaf types of nested dtypes (list, array, struct) using the supplied function.

pub fn can_cast_to(&self, to: &DataType) -> Option<bool>

Return whether the cast to to makes sense.

If it None, we are not sure.

pub fn implode(self) -> DataType

pub fn to_physical(&self) -> DataType

Convert to the physical data type

pub fn byte_width(&self) -> Option<f64>

Bytes one value of this type takes, or None when that depends on the value.

pub fn to_storage(&self) -> DataType

pub fn is_supported_list_arithmetic_input(&self) -> bool

pub fn is_supported_array_dot_input(&self) -> bool

Whether arr.dot has a kernel for this inner dtype.

pub fn is_logical(&self) -> bool

Check if this DataType is a logical type

pub fn is_temporal(&self) -> bool

Check if this DataType is a temporal type

pub fn is_primitive(&self) -> bool

Check if datatype is a primitive type. By that we mean that it is not a nested or logical type.

pub fn is_primitive_numeric(&self) -> bool

Check if this DataType is a primitive numeric type (excludes Decimal).

pub fn is_bool(&self) -> bool

Check if this DataType is a boolean.

pub fn is_list(&self) -> bool

Check if this DataType is a list.

pub fn is_array(&self) -> bool

Check if this DataType is an array.

pub fn is_nested(&self) -> bool

pub fn is_struct(&self) -> bool

Check if this DataType is a struct

pub fn is_map(&self) -> bool

Check if this DataType is a map

pub fn is_binary(&self) -> bool

pub fn is_date(&self) -> bool

pub fn is_datetime(&self) -> bool

pub fn is_duration(&self) -> bool

pub fn is_object(&self) -> bool

pub fn is_null(&self) -> bool

pub fn contains_views(&self) -> bool

pub fn contains_categoricals(&self) -> bool

pub fn contains_enums(&self) -> bool

pub fn contains_objects(&self) -> bool

pub fn contains_map(&self) -> bool

pub fn contains_list_recursive(&self) -> bool

pub fn contains_unknown(&self) -> bool

pub fn contains_dtype_recursive(&self, dtype: &DataType) -> bool

pub fn is_ord(&self) -> bool

Check if type is sortable

pub fn is_decimal(&self) -> bool

Check if this DataType is a Decimal type (of any scale/precision).

pub fn is_float(&self) -> bool

Check if this DataType is a basic floating point type (excludes Decimal). Note, this also includes Unknown(UnknownKind::Float).

pub fn is_integer(&self) -> bool

Check if this DataType is an integer. Note, this also includes Unknown(UnknownKind::Int).

pub fn is_signed_integer(&self) -> bool

pub fn is_unsigned_integer(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_categorical(&self) -> bool

pub fn is_enum(&self) -> bool

pub fn as_map(&self) -> Option<(&DataType, &DataType)>

Available on crate feature dtype-map only.

Return the key and value dtypes of a Map, or None for any other dtype.

pub fn map_entries_dtype(&self) -> Option<DataType>

Available on crate feature dtype-map only.

The Struct {key, value} entries dtype of this Map. Returns None for any other dtype.

pub fn map_storage_dtype(&self) -> Option<DataType>

Available on crate feature dtype-map only.

Returns the dtype of the Series used internally to store this Map: List(Struct {key, value}). Returns None for any other dtype.

This is intentionally separate from DataType::to_storage. Adding Map there would imply also unwrapping it in Series::to_storage. Python map_elements calls the latter, so each map row would reach the UDF as a List(Struct) value instead of a dict.

pub fn map_from_named_entries_dtype(&self) -> Result<DataType, PolarsError>

Available on crate feature dtype-map only.

The Map dtype whose entries are self, matching the key and value fields by name.

pub fn is_valid_map_key(&self) -> bool

Available on crate feature dtype-map only.

Whether this dtype may be used as the key dtype of a Map.

pub fn ensure_valid_map_key(&self) -> Result<(), PolarsError>

Available on crate feature dtype-map only.
pub fn is_valid_map_value(&self) -> bool

Available on crate feature dtype-map only.

Whether this dtype may be used as the value dtype of a Map.

pub fn ensure_valid_map_value(&self) -> Result<(), PolarsError>

Available on crate feature dtype-map only.
pub fn ensure_valid_map_dtype(&self) -> Result<(), PolarsError>

Available on crate feature dtype-map only.

Validate the key and value dtypes of a Map. Errors for any other dtype.

pub fn ensure_valid_map_dtypes(&self) -> Result<(), PolarsError>

Available on crate feature dtype-map only.

Validate every Map nested in this dtype. Unlike Self::ensure_valid_map_dtype, this accepts dtypes that are not a Map themselves.

pub fn is_extension(&self) -> bool

pub fn to_arrow_field( &self, name: PlSmallStr, compat_level: CompatLevel, ) -> Field

Convert to an Arrow Field.

pub fn to_arrow_field_metadata( &self, ) -> Option<BTreeMap<PlSmallStr, PlSmallStr>>

pub fn max(&self) -> Result<Scalar, PolarsError>

Try to get the maximum value for this datatype.

pub fn min(&self) -> Result<Scalar, PolarsError>

Try to get the minimum value for this datatype.

pub fn to_arrow(&self, compat_level: CompatLevel) -> ArrowDataType

Convert to an Arrow data type.

pub fn try_to_arrow( &self, compat_level: CompatLevel, ) -> Result<ArrowDataType, PolarsError>

pub fn is_nested_null(&self) -> bool

pub fn matches_schema_type( &self, schema_type: &DataType, ) -> Result<bool, PolarsError>

Answers if this type matches the given type of a schema.

Allows (nested) Null types in this type to match any type in the schema, but not vice versa. In such a case Ok(true) is returned, because a cast is necessary. If no cast is necessary Ok(false) is returned, and an error is returned if the types, container shapes, or Struct field names are incompatible.

pub fn is_unknown(&self) -> bool

pub fn nesting_level(&self) -> usize

pub fn cat_physical(&self) -> Result<CategoricalPhysical, PolarsError>

Available on crate feature dtype-categorical only.

If this dtype is a Categorical or Enum, returns the physical backing type.

pub fn cat_mapping(&self) -> Result<&Arc<CategoricalMapping>, PolarsError>

Available on crate feature dtype-categorical only.

If this dtype is a Categorical or Enum, returns the underlying mapping.

pub fn from_categories(cats: Arc<Categories>) -> DataType

Available on crate feature dtype-categorical only.
pub fn from_frozen_categories(fcats: Arc<FrozenCategories>) -> DataType

Available on crate feature dtype-categorical only.
pub fn is_numeric(&self) -> bool

pub fn numeric_to_unsigned_bit_repr(&self) -> Option<DataType>

Source

impl DataType

pub fn visit_with(&self, visitor_fn: impl FnMut(&DataType))

pub fn try_visit_with( &self, visitor_fn: impl FnMut(&DataType) -> Result<(), PolarsError>, ) -> Result<(), PolarsError>

pub fn try_mutate_with<'d>( dtype: Cow<'d, DataType>, visitor_fn: impl FnMut(Cow<'d, DataType>) -> Result<Cow<'d, DataType>, PolarsError>, ) -> Result<Cow<'d, DataType>, PolarsError>

Source

impl DataType

pub fn boxed(self) -> Box<DataType>

pub fn from_arrow_field(field: &Field) -> DataType

pub fn from_arrow_dtype(dt: &ArrowDataType) -> DataType

pub fn arrow_value_scale(dtype: &ArrowDataType) -> i64

The factor polars multiplies the values of an Arrow dtype by to store them as Self::from_arrow_dtype: Arrow seconds become milliseconds and every time of day nanoseconds, all other values stay as they are.

pub fn from_arrow( dt: &ArrowDataType, md: Option<&BTreeMap<PlSmallStr, PlSmallStr>>, ) -> DataType