slice_groups_are_monotonic

Function slice_groups_are_monotonic 

pub fn slice_groups_are_monotonic(groups: &Vec<[u32; 2]>) -> bool
Available on crate feature algorithm_group_by only.
Returns whether groups is monotonic: True if for every consecutive pair of group slices both the start and the end offset are non-decreasing.