ensure_matching_dtypes_if_found

Function ensure_matching_dtypes_if_found 

pub fn ensure_matching_dtypes_if_found(
    schema: &Schema<Field, BTreeMap<PlSmallStr, PlSmallStr>>,
    current_schema: &Schema<Field, BTreeMap<PlSmallStr, PlSmallStr>>,
) -> Result<(), PolarsError>
Available on crate feature polars-io only.
Utility to ensure the dtype of the column in current_schema matches the dtype in schema if that column exists in schema.