pub struct BufferByteSource(pub Buffer<u8>);Available on crate features
async and polars-io only.Expand description
Byte source backed by a Buffer, which can potentially be memory-mapped.
Tuple Fields
0: Buffer<u8>Trait Implementations
Sourceimpl ByteSource for BufferByteSource
impl ByteSource for BufferByteSource
async fn get_size(&self) -> Result<usize, PolarsError>
Sourceasync fn get_suffix(&self, n: usize) -> Result<(Buffer<u8>, usize), PolarsError>
async fn get_suffix(&self, n: usize) -> Result<(Buffer<u8>, usize), PolarsError>
Fetch the last
n bytes and the total size of the source, in a single request. Returns
fewer than n bytes if the source is smaller than n.Sourceasync fn get_range(
&self,
range: Range<usize>,
) -> Result<Buffer<u8>, PolarsError>
async fn get_range( &self, range: Range<usize>, ) -> Result<Buffer<u8>, PolarsError>
Panics Read more
Sourceasync fn get_ranges(
&self,
ranges: &mut [Range<usize>],
) -> Result<HashMap<usize, Buffer<u8>, RandomState>, PolarsError>
async fn get_ranges( &self, ranges: &mut [Range<usize>], ) -> Result<HashMap<usize, Buffer<u8>, RandomState>, PolarsError>
Note: This will mutably sort ranges for coalescing.
Sourceimpl From<BufferByteSource> for DynByteSource
impl From<BufferByteSource> for DynByteSource
Sourcefn from(value: BufferByteSource) -> DynByteSource
fn from(value: BufferByteSource) -> DynByteSource
Converts to this type from the input type.