pub struct FetchConfig {
pub chunk_size: usize,
pub strategy: ConcurrencyStrategy,
}Available on crate feature
polars-io only.Fields
chunk_size: usizestrategy: ConcurrencyStrategyImplementations
Sourceimpl FetchConfig
impl FetchConfig
Sourcepub fn random_access() -> FetchConfig
pub fn random_access() -> FetchConfig
Use for cloud-based file formats that are randomly accessible, i.e. individual row groups (or record batches) and/or individual columns can be fetched directly using the metadata as an input. Example: Parquet, IPC with internal extensions.
The chunk_size should be small enough to enable smooth operation of the bytes-based in-flight concurrency controller.
Sourcepub fn streaming() -> FetchConfig
pub fn streaming() -> FetchConfig
Use for cloud-based file formats that have a sequential layout, i.e. the file bytes must be fetched and parsed sequentially. The pipeline is responsible for managing back-pressure and rate-limiting. Example: CSV.
Sourcepub fn legacy() -> FetchConfig
pub fn legacy() -> FetchConfig
Used for legacy fetch. @TODO: Deprecate over time.