pub struct Pacer { /* private fields */ }Available on crate features
polars-io and cloud only.Expand description
Lock-free hot path enforcing the rate-limit by pacing requests through the token bucket.
Implementations
Sourceimpl Pacer
impl Pacer
Sourcepub fn start(bucket: Arc<TokenBucket>, max_wait: Duration) -> Arc<Pacer>
pub fn start(bucket: Arc<TokenBucket>, max_wait: Duration) -> Arc<Pacer>
Construct and spawn the wake tick. The tick is per-pacer.
Sourcepub async fn admit(&self) -> Result<(), HttpError>
pub async fn admit(&self) -> Result<(), HttpError>
Admit a request to the pacer, which may get queued internally. Returns a PacerBusy Error when the estimated wait exceeds the wait bound.
pub fn queue_depth(&self) -> u64
pub fn admitted(&self) -> u64
pub fn bucket(&self) -> &Arc<TokenBucket>