pub struct PacingBudget { /* private fields */ }Available on crate features
polars-io and cloud only.Expand description
Read-only view of the pacing budget including the learned rate-limit signal for internal consumers (e.g., ConcurrencyController). The cells contains learned rates (f64 bits in an AtomicU64), and are updated by the AIMD loop only. Valid for the process lifetime: object store rebuilds can rotate behind the cells rather than replacing them.
Implementations