pub enum JoinType {
Inner,
Left,
Right,
Full,
AsOf(Box<AsOfOptions>),
Semi,
Anti,
IEJoin,
Range,
Cross,
}Available on crate feature
lazy only.Variants
Inner
Left
Right
Full
AsOf(Box<AsOfOptions>)
Available on crate feature
asof_join only.Semi
Available on crate feature
semi_anti_join only.Anti
Available on crate feature
semi_anti_join only.IEJoin
Available on crate feature
iejoin only.Inequality join with two arbitrary predicates
Range
Available on crate feature
iejoin only.Inequality join with col ∈ [lo, hi] predicate
Cross
Implementations
Sourceimpl JoinType
impl JoinType
pub fn is_equi(&self) -> bool
pub fn is_semi_anti(&self) -> bool
pub fn is_semi(&self) -> bool
pub fn is_anti(&self) -> bool
pub fn is_asof(&self) -> bool
pub fn is_inner(&self) -> bool
pub fn is_cross(&self) -> bool
pub fn is_ie(&self) -> bool
pub fn is_range(&self) -> bool
Sourcepub fn emits_unmatched_left(&self) -> bool
pub fn emits_unmatched_left(&self) -> bool
Unmatched rows of the left input appear in the output.
Sourcepub fn emits_unmatched_right(&self) -> bool
pub fn emits_unmatched_right(&self) -> bool
Unmatched rows of the right input appear in the output.
Sourcepub fn supports_non_equi(&self) -> bool
pub fn supports_non_equi(&self) -> bool
Joins supported in join where with non-equi conditions
Sourcepub fn supports_non_equi_options(
&self,
options: &Option<JoinTypeOptions>,
) -> bool
pub fn supports_non_equi_options( &self, options: &Option<JoinTypeOptions>, ) -> bool
Whether the physical join implementations can execute this how with the given
(already-resolved) match-condition algorithm without silently dropping it.