Enum JoinValidation
pub enum JoinValidation {
ManyToMany,
ManyToOne,
OneToMany,
OneToOne,
}Variants
ManyToMany
No unique checks
ManyToOne
Check if join keys are unique in right dataset.
OneToMany
Check if join keys are unique in left dataset.
OneToOne
Check if join keys are unique in both left and right datasets
Implementations
impl JoinValidation
impl JoinValidation
pub fn needs_checks(&self) -> bool
pub fn swap(self, swap: bool) -> JoinValidation
pub fn is_valid_join(&self, join_type: &JoinType) -> Result<(), PolarsError>