pub enum AsyncWritable {
Dyn(AsyncDynWritable),
Local(File),
Cloud(CloudWriterIoTraitWrap),
}Available on crate feature
polars-io only.Expand description
Holds an async writable file, abstracted over local files or cloud files.
This implements DerefMut to a trait object implementing [tokio::io::AsyncWrite].
Note: It is important that you do not call shutdown() on the deref’ed AsyncWrite object.
You should instead call the AsyncWritable::close at the end.
Variants
Implementations
Sourceimpl AsyncWritable
impl AsyncWritable
pub async fn try_new( path: PlRefPath, cloud_options: Option<&CloudOptions>, cloud_upload_chunk_size: usize, cloud_upload_concurrency: usize, io_metrics: Option<Arc<IOMetrics>>, ) -> Result<AsyncWritable, PolarsError>
Sourcepub async fn write_all_owned<T>(&mut self, src: &mut T) -> Result<(), Error>
pub async fn write_all_owned<T>(&mut self, src: &mut T) -> Result<(), Error>
If this writer holds a cloud writer, it will mem::take(T). T is unmodified for other
writer types.
pub async fn sync_all(&mut self) -> Result<(), Error>
pub async fn sync_data(&mut self) -> Result<(), Error>
pub async fn close(self, sync: SyncOnCloseType) -> Result<(), PolarsError>