Function duration
pub fn duration(args: DurationArgs) -> ExprAvailable on crate features
dtype-duration and lazy only.Expand description
Construct a column of Duration from the provided DurationArgs
pub fn duration(args: DurationArgs) -> Exprdtype-duration and lazy only.Construct a column of Duration from the provided DurationArgs