map_get

Function map_get 

pub fn map_get(ca: &MapChunked, key: &Series) -> Result<Series, PolarsError>
Available on crate feature polars-ops only.
Look up key in every row of ca, returning the Map’s value dtype.

Missing keys, null keys and null Map rows yield null.