pipe_with_dtype

Function pipe_with_dtype 

pub fn pipe_with_dtype<E>(
    exprs: E,
    callback: PlanCallback<(Vec<Expr>, Vec<DataType>), Expr>,
) -> Expr
where E: AsRef<[Expr]>,
Available on crate feature lazy only.
Replace exprs, at plan time, with the expression returned by callback.

The callback receives the input expressions and their resolved dtypes, in the same order. Inputs that expand to multiple columns (e.g. selectors) are combined in the same way as other multi-input functions, calling callback once per combination.