pub struct ArrayNameSpace(pub Expr);Available on crate feature
lazy only.Expand description
Specialized expressions for Series of DataType::Array.
Tuple Fields
0: ExprImplementations
Sourceimpl ArrayNameSpace
impl ArrayNameSpace
Sourcepub fn unique_stable(self) -> Expr
pub fn unique_stable(self) -> Expr
Keep only the unique values in every sub-array.
pub fn n_unique(self) -> Expr
Sourcepub fn to_list(self) -> Expr
pub fn to_list(self) -> Expr
Cast the Array column to List column with the same inner data type.
pub fn sort(self, options: SortOptions) -> Expr
pub fn reverse(self) -> Expr
pub fn arg_min(self) -> Expr
pub fn arg_max(self) -> Expr
Sourcepub fn get(self, index: Expr, null_on_oob: bool) -> Expr
pub fn get(self, index: Expr, null_on_oob: bool) -> Expr
Get items in every sub-array by index.
Sourcepub fn join(self, separator: Expr, ignore_nulls: bool) -> Expr
pub fn join(self, separator: Expr, ignore_nulls: bool) -> Expr
Join all string items in a sub-array and place a separator between them.
Error
Raise if inner type of array is not DataType::String.
Sourcepub fn contains<E>(self, other: E, nulls_equal: bool) -> Expr
Available on crate feature is_in only.
pub fn contains<E>(self, other: E, nulls_equal: bool) -> Expr
is_in only.Check if the sub-array contains specific element
Sourcepub fn slice(
self,
offset: Expr,
length: Expr,
as_array: bool,
) -> Result<Expr, PolarsError>
pub fn slice( self, offset: Expr, length: Expr, as_array: bool, ) -> Result<Expr, PolarsError>
Slice every subarray.
Sourcepub fn head(self, n: Expr, as_array: bool) -> Result<Expr, PolarsError>
pub fn head(self, n: Expr, as_array: bool) -> Result<Expr, PolarsError>
Get the head of every subarray
Sourcepub fn tail(self, n: Expr, as_array: bool) -> Result<Expr, PolarsError>
pub fn tail(self, n: Expr, as_array: bool) -> Result<Expr, PolarsError>
Get the tail of every subarray
Sourcepub fn explode(self, options: ExplodeOptions) -> Expr
pub fn explode(self, options: ExplodeOptions) -> Expr
Returns a column with a separate row for every array element.
pub fn eval<E>(self, other: E, as_list: bool) -> Expr
pub fn agg<E>(self, other: E) -> Expr