Struct AsOfOptions
pub struct AsOfOptions {
pub strategy: AsofStrategy,
pub tolerance: Option<Scalar>,
pub tolerance_str: Option<PlSmallStr>,
pub left_by: Option<Vec<PlSmallStr>>,
pub right_by: Option<Vec<PlSmallStr>>,
pub allow_eq: bool,
pub check_sortedness: bool,
}Available on crate feature
asof_join only.Fields
strategy: AsofStrategytolerance: Option<Scalar>A tolerance in the same unit as the asof column
tolerance_str: Option<PlSmallStr>A time duration specified as a string, for example:
- “5m”
- “2h15m”
- “1d6h”
left_by: Option<Vec<PlSmallStr>>right_by: Option<Vec<PlSmallStr>>allow_eq: boolAllow equal matches
check_sortedness: boolTrait Implementations
impl Clone for AsOfOptions
impl Clone for AsOfOptions
fn clone(&self) -> AsOfOptions
fn clone(&self) -> AsOfOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for AsOfOptions
impl Debug for AsOfOptions
impl Default for AsOfOptions
impl Default for AsOfOptions
fn default() -> AsOfOptions
fn default() -> AsOfOptions
Returns the “default value” for a type. Read more
impl<'de> Deserialize<'de> for AsOfOptions
impl<'de> Deserialize<'de> for AsOfOptions
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AsOfOptions, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AsOfOptions, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Hash for AsOfOptions
impl Hash for AsOfOptions
impl PartialEq for AsOfOptions
impl PartialEq for AsOfOptions
impl Serialize for AsOfOptions
impl Serialize for AsOfOptions
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AsOfOptions