Duration

Struct Duration 

pub struct Duration {
    pub negative: bool,
    pub parsed_int: bool,
    /* private fields */
}

Fields

negative: boolparsed_int: bool

Implementations



impl Duration

pub const fn new(fixed_slots: i64) -> Duration

Create a new integer size Duration

pub fn parse(duration: &str) -> Duration

Parse a string into a Duration

Strings are composed of a sequence of number-unit pairs, such as 5d (5 days). A string may begin with a minus sign, in which case it is interpreted as a negative duration. Some examples:

  • "1y": 1 year
  • "-1w2d": negative 1 week, 2 days (i.e. -9 days)
  • "3d12h4m25s": 3 days, 12 hours, 4 minutes, and 25 seconds

Aside from a leading minus sign, strings may not contain any characters other than numbers and letters (including whitespace).

The available units, in ascending order of magnitude, are as follows:

  • ns: nanosecond
  • us: microsecond
  • ms: millisecond
  • s: second
  • m: minute
  • h: hour
  • d: day
  • w: week
  • mo: calendar month
  • q: calendar quarter
  • y: calendar year
  • i: index value (only for {Int32, Int64} dtypes)

By “calendar day”, we mean the corresponding time on the next day (which may not be 24 hours, depending on daylight savings). Similarly for “calendar week”, “calendar month”, “calendar quarter”, and “calendar year”.

Panics

If the given str is invalid for any reason.

pub fn try_parse(duration: &str) -> Result<Duration, PolarsError>

pub fn try_parse_interval(interval: &str) -> Result<Duration, PolarsError>

pub fn from_nsecs(v: i64) -> Duration

Creates a Duration that represents a fixed number of nanoseconds.

pub fn is_zero(&self) -> bool

true if zero duration.

pub fn months_only(&self) -> bool

pub fn months(&self) -> i64

pub fn weeks_only(&self) -> bool

pub fn weeks(&self) -> i64

pub fn days_only(&self) -> bool

pub fn days(&self) -> i64

pub fn is_full_days(&self) -> bool

Returns whether the duration consists of full days.

Note that 24 hours is not considered a full day due to possible daylight savings time transitions.

pub fn is_constant_duration(&self, time_zone: Option<&TimeZone>) -> bool

pub fn nanoseconds(&self) -> i64

Returns the nanoseconds from the Duration without the weeks or months part.

pub fn negative(&self) -> bool

Returns whether duration is negative.

pub fn truncate_impl<F, G, J>( &self, t: i64, tz: Option<&Tz>, nsecs_to_unit: F, timestamp_to_datetime: G, datetime_to_timestamp: J, ) -> Result<i64, PolarsError>
where F: Fn(i64) -> i64, G: Fn(i64) -> NaiveDateTime, J: Fn(NaiveDateTime) -> i64,

pub fn truncate_ns(&self, t: i64, tz: Option<&Tz>) -> Result<i64, PolarsError>

Available on crate feature temporal only.

pub fn truncate_us(&self, t: i64, tz: Option<&Tz>) -> Result<i64, PolarsError>

Available on crate feature temporal only.

pub fn truncate_ms(&self, t: i64, tz: Option<&Tz>) -> Result<i64, PolarsError>

Available on crate feature temporal only.

pub fn add_ns(&self, t: i64, tz: Option<&Tz>) -> Result<i64, PolarsError>

Available on crate feature temporal only.

pub fn add_us(&self, t: i64, tz: Option<&Tz>) -> Result<i64, PolarsError>

Available on crate feature temporal only.

pub fn add_ms(&self, t: i64, tz: Option<&Tz>) -> Result<i64, PolarsError>

Available on crate feature temporal only.