Struct IndexRange
pub struct IndexRange { /* private fields */ }Expand description
A half-open range start..end of index values in the physical i64 space of the index
column: Datetime in its own time unit, Date as microseconds, integers as themselves.
(i64::MIN, None) stands for an unbounded range.
Implementations
impl IndexRange
impl IndexRange
pub const ALL: IndexRange
pub const fn new(start: i64, end: Option<i64>) -> IndexRange
pub const fn new(start: i64, end: Option<i64>) -> IndexRange
The range start..end.
pub fn start(&self) -> i64
pub fn end(&self) -> Option<i64>
pub fn contains(&self, t: i64) -> bool
pub fn is_before(&self, t: i64) -> bool
pub fn is_before(&self, t: i64) -> bool
Whether t, and so every earlier value of an ascending index, lies before the range.