pub struct IsInHaystack { /* private fields */ }Available on crate feature
polars-ops only.Expand description
A single haystack prepared for probing with needles of a fixed dtype.
Implementations
Sourceimpl IsInHaystack
impl IsInHaystack
Sourcepub fn new(
haystack: &Series,
needle_dtype: &DataType,
) -> Result<IsInHaystack, PolarsError>
pub fn new( haystack: &Series, needle_dtype: &DataType, ) -> Result<IsInHaystack, PolarsError>
haystack must be a List or Array series of length 1.
pub fn probe( &self, needle: &Series, nulls_equal: bool, ) -> Result<ChunkedArray<BooleanType>, PolarsError>