JoinBuilder

Struct JoinBuilder 

pub struct JoinBuilder { /* private fields */ }
Available on crate feature lazy only.

Implementations

Source

impl JoinBuilder

pub fn new(lf: LazyFrame) -> JoinBuilder

Create the JoinBuilder with the provided LazyFrame as the left table.

pub fn with(self, other: LazyFrame) -> JoinBuilder

The right table in the join.

pub fn how(self, how: JoinType) -> JoinBuilder

Select the join type.

pub fn validate(self, validation: JoinValidation) -> JoinBuilder

pub fn on<E>(self, on: E) -> JoinBuilder
where E: AsRef<[Expr]>,

The expressions you want to join both tables on.

The passed expressions must be valid in both LazyFrames in the join. Selectors expand independently against each input schema. The results are paired in order and both sides must produce the same nonzero number of keys.

pub fn left_on<E>(self, on: E) -> JoinBuilder
where E: AsRef<[Expr]>,

The expressions you want to join the left table on.

The passed expressions and selectors must be valid in the left table. The total expanded key count must be nonzero and match the right side.

pub fn right_on<E>(self, on: E) -> JoinBuilder
where E: AsRef<[Expr]>,

The expressions you want to join the right table on.

The passed expressions and selectors must be valid in the right table. The total expanded key count must be nonzero and match the left side.

pub fn allow_parallel(self, allow: bool) -> JoinBuilder

Allow parallel table evaluation.

pub fn force_parallel(self, force: bool) -> JoinBuilder

Force parallel table evaluation.

pub fn join_nulls(self, nulls_equal: bool) -> JoinBuilder

Join on null values. By default null values will never produce matches.

pub fn suffix<S>(self, suffix: S) -> JoinBuilder
where S: Into<PlSmallStr>,

Suffix to add duplicate column names in join. Defaults to "_right" if this method is never called.

pub fn coalesce(self, coalesce: JoinCoalesce) -> JoinBuilder

Whether to coalesce join columns.

pub fn maintain_order(self, maintain_order: MaintainOrderJoin) -> JoinBuilder

Whether to preserve the row order.

pub fn build_side(self, build_side: Option<JoinBuildSide>) -> JoinBuilder

Whether to prefer a specific build side.

pub fn finish(self) -> Result<LazyFrame, PolarsError>

Finish builder

pub fn join_where(self, predicates: Vec<Expr>) -> LazyFrame