pub struct Window {
pub offset: Duration,
/* private fields */
}Available on crate feature
temporal only.Expand description
Represents a window in time
Fields
offset: DurationImplementations
Sourceimpl Window
impl Window
pub fn new(every: Duration, period: Duration, offset: Duration) -> Window
Sourcepub fn truncate(
&self,
tu: TimeUnit,
t: i64,
tz: Option<&Tz>,
) -> Result<i64, PolarsError>
pub fn truncate( &self, tu: TimeUnit, t: i64, tz: Option<&Tz>, ) -> Result<i64, PolarsError>
Truncate the given timestamp in tu by the window boundary.
Sourcepub fn round(
&self,
tu: TimeUnit,
t: i64,
tz: Option<&Tz>,
) -> Result<i64, PolarsError>
pub fn round( &self, tu: TimeUnit, t: i64, tz: Option<&Tz>, ) -> Result<i64, PolarsError>
Round the given timestamp in tu by the window boundary.
Sourcepub fn get_earliest_bounds(
&self,
tu: TimeUnit,
t: i64,
closed_window: ClosedWindow,
tz: Option<&Tz>,
) -> Result<Bounds, PolarsError>
pub fn get_earliest_bounds( &self, tu: TimeUnit, t: i64, closed_window: ClosedWindow, tz: Option<&Tz>, ) -> Result<Bounds, PolarsError>
returns the bounds for the earliest window bounds that contains the given time t. For underlapping windows that do not contain time t, the window directly after time t will be returned.
pub fn get_overlapping_bounds_iter<'a>( &'a self, boundary: Bounds, closed_window: ClosedWindow, tu: TimeUnit, tz: Option<&'a Tz>, start_by: StartBy, origin: Option<i64>, ) -> Result<BoundsIter<'a>, PolarsError>
Sourcepub fn first_window_start(
&self,
t0: i64,
closed_window: ClosedWindow,
tu: TimeUnit,
tz: Option<&Tz>,
start_by: StartBy,
) -> Result<i64, PolarsError>
pub fn first_window_start( &self, t0: i64, closed_window: ClosedWindow, tu: TimeUnit, tz: Option<&Tz>, start_by: StartBy, ) -> Result<i64, PolarsError>
The start of the first window for data whose first value is t0, as placed by
start_by, every and offset.