pub trait RoundSeries: SeriesSealed {
// Provided methods
fn round(
&self,
decimals: u32,
mode: RoundMode,
) -> Result<Series, PolarsError> { ... }
fn round_sig_figs(&self, digits: i32) -> Result<Series, PolarsError> { ... }
fn truncate(&self, decimals: u32) -> Result<Series, PolarsError> { ... }
fn floor(&self) -> Result<Series, PolarsError> { ... }
fn ceil(&self) -> Result<Series, PolarsError> { ... }
}Available on crate feature
polars-ops only.Provided Methods
Sourcefn round(&self, decimals: u32, mode: RoundMode) -> Result<Series, PolarsError>
fn round(&self, decimals: u32, mode: RoundMode) -> Result<Series, PolarsError>
Round underlying floating point array to the given number of decimals.
Sourcefn round_sig_figs(&self, digits: i32) -> Result<Series, PolarsError>
fn round_sig_figs(&self, digits: i32) -> Result<Series, PolarsError>
Round underlying floating point array to the given number of significant digits.
Sourcefn truncate(&self, decimals: u32) -> Result<Series, PolarsError>
fn truncate(&self, decimals: u32) -> Result<Series, PolarsError>
Truncate underlying floating point array toward zero to the given number of decimals.
Sourcefn floor(&self) -> Result<Series, PolarsError>
fn floor(&self) -> Result<Series, PolarsError>
Floor underlying floating point array to the lowest integers smaller or equal to the float value.
Sourcefn ceil(&self) -> Result<Series, PolarsError>
fn ceil(&self) -> Result<Series, PolarsError>
Ceil underlying floating point array to the highest integers smaller or equal to the float value.