pub struct CategoricalToArrowConverter {
pub converters: IndexMap<usize, CategoricalArrayToArrowConverter, RandomState>,
pub persist_remap: bool,
}Available on crate feature
dtype-categorical only.Expand description
Categorical converter that prunes unused categories.
Fields
converters: IndexMap<usize, CategoricalArrayToArrowConverter, RandomState>Converters keyed by the Arc address of Arc<CategoricalMapping>.
Safety
The usize key remains valid as CategoricalArrayToArrowConverter holds a ref-count to the
Arc<> that the key is derived from.
persist_remap: boolPersist the key remap to ensure consistent mapping across multiple calls.
Implementations
Sourceimpl CategoricalToArrowConverter
impl CategoricalToArrowConverter
Sourcepub fn initialize(&mut self, dtype: &DataType)
pub fn initialize(&mut self, dtype: &DataType)
Initializes categorical converters for all categorical mappings present in this dtype.