ToArrowConverter

Struct ToArrowConverter 

pub struct ToArrowConverter {
    pub skip_attach_pl_metadata: bool,
    pub categorical_converter: CategoricalToArrowConverter,
}
Low-level converter that exports ArrayRefs from Polars Series to arrow arrays.

This can be held to perform repeated categorical exports with persisted indices to ensure the exported chunks use the same set of indices.

Fields

skip_attach_pl_metadata: bool

If the arrow_field being passed was generated by DataType::to_arrow_field, it will already have polars metadata.

categorical_converter: CategoricalToArrowConverter
Available on crate feature dtype-categorical only.

Implementations

Source

impl ToArrowConverter

pub fn array_to_arrow<'a>( &mut self, array: &(dyn Array + 'static), dtype: &DataType, arrow_field: Cow<'a, Field>, ) -> Result<Box<dyn Array>, PolarsError>

Returns an error if output_arrow_field was provided and does not match the output data type.