pub struct SeriesBuilder { /* private fields */ }Expand description
A type-erased wrapper around ArrayBuilder.
Implementations
Sourceimpl SeriesBuilder
impl SeriesBuilder
pub fn new(dtype: DataType) -> SeriesBuilder
pub fn reserve(&mut self, additional: usize)
pub fn freeze(self, name: PlSmallStr) -> Series
pub fn freeze_reset(&mut self, name: PlSmallStr) -> Series
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn dtype(&self) -> &DataType
Sourcepub fn extend_nulls(&mut self, length: usize)
pub fn extend_nulls(&mut self, length: usize)
Extend this builder with the given number of null elements.
Sourcepub fn extend(&mut self, other: &Series, share: ShareStrategy)
pub fn extend(&mut self, other: &Series, share: ShareStrategy)
Extends this builder with the contents of the given series. May panic if other does not match the dtype of this builder.
Sourcepub fn subslice_extend(
&mut self,
other: &Series,
start: usize,
length: usize,
share: ShareStrategy,
)
pub fn subslice_extend( &mut self, other: &Series, start: usize, length: usize, share: ShareStrategy, )
Extends this builder with the contents of the given series subslice. May panic if other does not match the dtype of this builder.
pub fn subslice_extend_repeated( &mut self, other: &Series, start: usize, length: usize, repeats: usize, share: ShareStrategy, )
pub fn subslice_extend_each_repeated( &mut self, other: &Series, start: usize, length: usize, repeats: usize, share: ShareStrategy, )
Sourcepub unsafe fn gather_extend(
&mut self,
other: &Series,
idxs: &[u32],
share: ShareStrategy,
)
pub unsafe fn gather_extend( &mut self, other: &Series, idxs: &[u32], share: ShareStrategy, )
Extends this builder with the contents of the given series at the given
indices. That is, other[idxs[i]] is appended to this builder in order,
for each i=0..idxs.len(). May panic if other does not match the dtype
of this builder, or if the other series is not rechunked.
Safety
The indices must be in-bounds.
pub fn opt_gather_extend( &mut self, other: &Series, idxs: &[u32], share: ShareStrategy, )
pub fn push_any_value(&mut self, value: AnyValue<'static>)